==> gpytorch-1.2.1.tar.gz: gpytorch-1.2.1/gpytorch/variational/__init__.py <==
#!/usr/bin/env python3

from ._variational_distribution import _VariationalDistribution
from ._variational_strategy import _VariationalStrategy
from .additive_grid_interpolation_variational_strategy import AdditiveGridInterpolationVariationalStrategy
from .batch_decoupled_variational_strategy import BatchDecoupledVariationalStrategy
from .cholesky_variational_distribution import CholeskyVariationalDistribution
from .delta_variational_distribution import DeltaVariationalDistribution
from .grid_interpolation_variational_strategy import GridInterpolationVariationalStrategy
from .independent_multitask_variational_strategy import (
    IndependentMultitaskVariationalStrategy,
    MultitaskVariationalStrategy,
)
from .lmc_variational_strategy import LMCVariationalStrategy
from .mean_field_variational_distribution import MeanFieldVariationalDistribution
from .natural_variational_distribution import NaturalVariationalDistribution, _NaturalVariationalDistribution
from .orthogonally_decoupled_variational_strategy import OrthogonallyDecoupledVariationalStrategy
from .tril_natural_variational_distribution import TrilNaturalVariationalDistribution
from .unwhitened_variational_strategy import UnwhitenedVariationalStrategy
from .variational_strategy import VariationalStrategy
from .whitened_variational_strategy import WhitenedVariationalStrategy

__all__ = [
    "_VariationalStrategy",
    "AdditiveGridInterpolationVariationalStrategy",
    "BatchDecoupledVariationalStrategy",
    "GridInterpolationVariationalStrategy",
    "IndependentMultitaskVariationalStrategy",
    "LMCVariationalStrategy",
    "MultitaskVariationalStrategy",
    "OrthogonallyDecoupledVariationalStrategy",
    "VariationalStrategy",
    "UnwhitenedVariationalStrategy",
    "WhitenedVariationalStrategy",
    "_VariationalDistribution",
    "CholeskyVariationalDistribution",
    "MeanFieldVariationalDistribution",
    "DeltaVariationalDistribution",
    "_NaturalVariationalDistribution",
    "NaturalVariationalDistribution",
    "TrilNaturalVariationalDistribution",
]

==> gpytorch-1.9.0.tar.gz: gpytorch-1.9.0/gpytorch/variational/__init__.py <==
#!/usr/bin/env python3

from ._variational_distribution import _VariationalDistribution
from ._variational_strategy import _VariationalStrategy
from .additive_grid_interpolation_variational_strategy import AdditiveGridInterpolationVariationalStrategy
from .batch_decoupled_variational_strategy import BatchDecoupledVariationalStrategy
from .cholesky_variational_distribution import CholeskyVariationalDistribution
from .ciq_variational_strategy import CiqVariationalStrategy
from .delta_variational_distribution import DeltaVariationalDistribution
from .grid_interpolation_variational_strategy import GridInterpolationVariationalStrategy
from .independent_multitask_variational_strategy import (
    IndependentMultitaskVariationalStrategy,
    MultitaskVariationalStrategy,
)
from .lmc_variational_strategy import LMCVariationalStrategy
from .mean_field_variational_distribution import MeanFieldVariationalDistribution
from .natural_variational_distribution import NaturalVariationalDistribution, _NaturalVariationalDistribution
from .nearest_neighbor_variational_strategy import NNVariationalStrategy
from .orthogonally_decoupled_variational_strategy import OrthogonallyDecoupledVariationalStrategy
from .tril_natural_variational_distribution import TrilNaturalVariationalDistribution
from .unwhitened_variational_strategy import UnwhitenedVariationalStrategy
from .variational_strategy import VariationalStrategy

__all__ = [
    "_VariationalStrategy",
    "AdditiveGridInterpolationVariationalStrategy",
    "BatchDecoupledVariationalStrategy",
    "CiqVariationalStrategy",
    "GridInterpolationVariationalStrategy",
    "IndependentMultitaskVariationalStrategy",
    "LMCVariationalStrategy",
    "MultitaskVariationalStrategy",
    "OrthogonallyDecoupledVariationalStrategy",
    "VariationalStrategy",
    "UnwhitenedVariationalStrategy",
    "_VariationalDistribution",
    "CholeskyVariationalDistribution",
    "MeanFieldVariationalDistribution",
    "DeltaVariationalDistribution",
    "_NaturalVariationalDistribution",
    "NaturalVariationalDistribution",
    "TrilNaturalVariationalDistribution",
    "NNVariationalStrategy",
]
